@@ -1,9 +1,11 @@
 use libc::{c_char, c_int, c_void};
-use object::PyObject;
-use pystate::PyThreadState;
+
+use crate::object::PyObject;
+use crate::pystate::PyThreadState;
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
+    #[deprecated(since = "0.5.2", note = "Deprecated since Python 3.9")]
     pub fn PyEval_CallObjectWithKeywords(
         callable: *mut PyObject,
         obj: *mut PyObject,
@@ -12,17 +14,21 @@ extern "C" {
 }
 
 #[inline]
+#[deprecated(since = "0.5.2", note = "Deprecated since Python 3.9")]
 pub unsafe fn PyEval_CallObject(callable: *mut PyObject, arg: *mut PyObject) -> *mut PyObject {
-    PyEval_CallObjectWithKeywords(callable, arg, ::core::ptr::null_mut())
+    #[allow(deprecated)]
+    PyEval_CallObjectWithKeywords(callable, arg, core::ptr::null_mut())
 }
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
+    #[deprecated(since = "0.5.2", note = "Deprecated since Python 3.9")]
     pub fn PyEval_CallFunction(
         callable: *mut PyObject,
         format: *const c_char,
         ...
     ) -> *mut PyObject;
+    #[deprecated(since = "0.5.2", note = "Deprecated since Python 3.9")]
     pub fn PyEval_CallMethod(
         obj: *mut PyObject,
         name: *const c_char,
@@ -32,7 +38,7 @@ extern "C" {
     pub fn PyEval_GetBuiltins() -> *mut PyObject;
     pub fn PyEval_GetGlobals() -> *mut PyObject;
     pub fn PyEval_GetLocals() -> *mut PyObject;
-    pub fn PyEval_GetFrame() -> *mut ::PyFrameObject;
+    pub fn PyEval_GetFrame() -> *mut crate::PyFrameObject;
     pub fn Py_AddPendingCall(
         func: Option<extern "C" fn(arg1: *mut c_void) -> c_int>,
         arg: *mut c_void,
@@ -41,11 +47,16 @@ extern "C" {
     pub fn Py_SetRecursionLimit(arg1: c_int) -> ();
     pub fn Py_GetRecursionLimit() -> c_int;
 
-    fn _Py_CheckRecursiveCall(_where: *mut c_char) -> c_int;
-    static mut _Py_CheckRecursionLimit: c_int;
+    //fn _Py_CheckRecursiveCall(_where: *mut c_char) -> c_int;
+    //static mut _Py_CheckRecursionLimit: c_int;
+
+    #[cfg(Py_3_9)]
+    pub fn Py_EnterRecursiveCall(_where: *const c_char) -> c_int;
+    #[cfg(Py_3_9)]
+    pub fn Py_LeaveRecursiveCall() -> c_void;
 }
 
-// TODO: Py_EnterRecursiveCall etc.
+// TODO: Py_EnterRecursiveCall for Python <3.9
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
@@ -53,8 +64,8 @@ extern "C" {
     pub fn PyEval_GetFuncDesc(arg1: *mut PyObject) -> *const c_char;
     #[cfg(not(Py_3_7))]
     pub fn PyEval_GetCallStats(arg1: *mut PyObject) -> *mut PyObject;
-    pub fn PyEval_EvalFrame(arg1: *mut ::PyFrameObject) -> *mut PyObject;
-    pub fn PyEval_EvalFrameEx(f: *mut ::PyFrameObject, exc: c_int) -> *mut PyObject;
+    pub fn PyEval_EvalFrame(arg1: *mut crate::PyFrameObject) -> *mut PyObject;
+    pub fn PyEval_EvalFrameEx(f: *mut crate::PyFrameObject, exc: c_int) -> *mut PyObject;
     pub fn PyEval_SaveThread() -> *mut PyThreadState;
     pub fn PyEval_RestoreThread(arg1: *mut PyThreadState) -> ();
 }
