@@ -1,8 +1,9 @@
-use code::*;
 use libc::{c_char, c_int};
-use object::PyObject;
-use pyarena::*;
-use pythonrun::*;
+
+use crate::code::*;
+use crate::object::PyObject;
+use crate::pyarena::*;
+use crate::pythonrun::*;
 
 #[repr(C)]
 #[derive(Copy, Clone)]
@@ -74,3 +75,5 @@ pub const Py_file_input: c_int = 257;
 pub const Py_eval_input: c_int = 258;
 #[cfg(Py_3_8)]
 pub const Py_func_type_input: c_int = 345;
+#[cfg(Py_3_9)]
+pub const Py_fstring_input: c_int = 800;
