@@ -1,8 +1,10 @@
-use code::{PyCodeObject, CO_MAXBLOCKS};
 use libc::{c_char, c_int};
-use object::*;
-use pystate::PyThreadState;
 
+use crate::code::{PyCodeObject, CO_MAXBLOCKS};
+use crate::object::*;
+use crate::pystate::PyThreadState;
+
+#[cfg(not(Py_LIMITED_API))]
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyTryBlock {
@@ -11,6 +13,10 @@ pub struct PyTryBlock {
     pub b_level: c_int,
 }
 
+#[cfg(Py_LIMITED_API)]
+pub enum PyFrameObject {}
+
+#[cfg(not(Py_LIMITED_API))]
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyFrameObject {
@@ -59,16 +65,19 @@ pub struct PyFrameObject {
     pub f_localsplus: [*mut PyObject; 1], /* locals+stack, dynamically sized */
 }
 
+#[cfg(not(Py_LIMITED_API))]
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
     pub static mut PyFrame_Type: PyTypeObject;
 }
 
+#[cfg(not(Py_LIMITED_API))]
 #[inline]
 pub unsafe fn PyFrame_Check(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == &mut PyFrame_Type) as c_int
 }
 
+#[cfg(not(Py_LIMITED_API))]
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
     pub fn PyFrame_New(
@@ -91,6 +100,14 @@ extern "C" {
     pub fn PyFrame_FastToLocalsWithError(f: *mut PyFrameObject) -> c_int;
     pub fn PyFrame_FastToLocals(f: *mut PyFrameObject) -> ();
 
+    #[cfg(not(Py_3_9))]
     pub fn PyFrame_ClearFreeList() -> c_int;
+}
+
+#[cfg_attr(windows, link(name = "pythonXY"))]
+extern "C" {
     pub fn PyFrame_GetLineNumber(f: *mut PyFrameObject) -> c_int;
+
+    #[cfg(Py_3_9)]
+    pub fn PyFrame_GetCode(frame: *mut PyFrameObject) -> *mut PyCodeObject;
 }
