@@ -1,5 +1,5 @@
 #![no_std]
-#![allow(non_camel_case_types, non_snake_case, non_upper_case_globals)]
+#![allow(non_camel_case_types, non_snake_case, non_upper_case_globals, unused_parens)]
 #![cfg_attr(Py_LIMITED_API, allow(unused_imports))]
 
 // old: marked with TODO
@@ -9,63 +9,64 @@
 // new:
 // Based on the headers of Python 3.3.0, 3.4.0 and 3.5.0.
 
-extern crate libc;
-
-pub use bltinmodule::*;
-pub use boolobject::*;
-pub use bytearrayobject::*;
-pub use bytesobject::*;
-pub use ceval::*;
-pub use code::*;
-pub use codecs::*;
-pub use compile::*;
-pub use complexobject::*;
-pub use descrobject::*;
-pub use dictobject::*;
-pub use enumobject::*;
-pub use eval::*;
-pub use fileobject::*;
+pub use crate::bltinmodule::*;
+pub use crate::boolobject::*;
+pub use crate::bytearrayobject::*;
+pub use crate::bytesobject::*;
+pub use crate::ceval::*;
+pub use crate::code::*;
+pub use crate::codecs::*;
+pub use crate::compile::*;
+pub use crate::complexobject::*;
+pub use crate::descrobject::*;
+pub use crate::dictobject::*;
+pub use crate::enumobject::*;
+pub use crate::eval::*;
+pub use crate::fileobject::*;
 #[cfg(Py_3_5)]
-pub use fileutils::*;
-pub use floatobject::*;
-pub use frameobject::PyFrameObject;
-pub use import::*;
-pub use intrcheck::*;
-pub use iterobject::*;
-pub use listobject::*;
-pub use longobject::*;
-pub use marshal::*;
-pub use memoryobject::*;
-pub use methodobject::*;
-pub use modsupport::*;
-pub use moduleobject::*;
-pub use object::*;
-pub use objectabstract::*;
-pub use objimpl::*;
+pub use crate::fileutils::*;
+pub use crate::floatobject::*;
+pub use crate::frameobject::PyFrameObject;
+pub use crate::import::*;
+#[cfg(all(Py_3_8, not(Py_LIMITED_API)))]
+pub use crate::initconfig::*;
+pub use crate::intrcheck::*;
+pub use crate::iterobject::*;
+pub use crate::listobject::*;
+pub use crate::longobject::*;
+pub use crate::marshal::*;
+pub use crate::memoryobject::*;
+pub use crate::methodobject::*;
+pub use crate::modsupport::*;
+pub use crate::moduleobject::*;
+pub use crate::object::*;
+pub use crate::objectabstract::*;
+pub use crate::objimpl::*;
 #[cfg(Py_3_6)]
-pub use osmodule::*;
-pub use pyarena::*;
-pub use pycapsule::*;
-pub use pydebug::*;
-pub use pyerrors::*;
+pub use crate::osmodule::*;
+pub use crate::pyarena::*;
+pub use crate::pycapsule::*;
+pub use crate::pydebug::*;
+pub use crate::pyerrors::*;
 #[cfg(Py_3_4)]
-pub use pyhash::*;
-pub use pymem::*;
-pub use pyport::*;
-pub use pystate::*;
-pub use pystrtod::*;
-pub use pythonrun::*;
-pub use rangeobject::*;
-pub use setobject::*;
-pub use sliceobject::*;
-pub use structseq::*;
-pub use sysmodule::*;
-pub use traceback::*;
-pub use tupleobject::*;
-pub use typeslots::*;
-pub use unicodeobject::*;
-pub use warnings::*;
-pub use weakrefobject::*;
+pub use crate::pyhash::*;
+pub use crate::pylifecycle::*;
+pub use crate::pymem::*;
+pub use crate::pyport::*;
+pub use crate::pystate::*;
+pub use crate::pystrtod::*;
+pub use crate::pythonrun::*;
+pub use crate::rangeobject::*;
+pub use crate::setobject::*;
+pub use crate::sliceobject::*;
+pub use crate::structseq::*;
+pub use crate::sysmodule::*;
+pub use crate::traceback::*;
+pub use crate::tupleobject::*;
+pub use crate::typeslots::*;
+pub use crate::unicodeobject::*;
+pub use crate::warnings::*;
+pub use crate::weakrefobject::*;
 
 mod pyport;
 
@@ -216,8 +217,7 @@ mod modsupport;
 // TODO some functions need to be moved to pylifecycle
 mod pythonrun;
 
-// TODO new in 3.5
-// mod pylifecycle;
+mod pylifecycle;
 
 // TODO supports PEP-384 only; needs adjustment for Python 3.3 and 3.5
 mod ceval;
@@ -277,12 +277,9 @@ mod fileutils;
 // TODO supports PEP-384 only; needs adjustment for Python 3.3 and 3.5
 pub mod structmember;
 
-#[cfg(not(Py_LIMITED_API))]
 pub mod frameobject;
 
-#[cfg(Py_LIMITED_API)]
-pub mod frameobject {
-    pub enum PyFrameObject {}
-}
-
 mod marshal;
+
+#[cfg(all(Py_3_8, not(Py_LIMITED_API)))]
+mod initconfig;
