@@ -1,9 +1,12 @@
 use libc::{c_char, c_int, c_long};
+
 #[cfg(Py_3_5)]
-use methodobject::PyMethodDef;
-use moduleobject::PyModuleDef;
-use object::PyObject;
-use pyport::Py_ssize_t;
+use crate::methodobject::PyMethodDef;
+#[cfg(Py_3_9)]
+use crate::object::PyTypeObject;
+use crate::moduleobject::PyModuleDef;
+use crate::object::PyObject;
+use crate::pyport::Py_ssize_t;
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
@@ -41,6 +44,8 @@ extern "C" {
         arg2: *const c_char,
         arg3: *const c_char,
     ) -> c_int;
+    #[cfg(Py_3_9)]
+    pub fn PyModule_AddType(module: *mut PyObject, ty: *mut PyTypeObject) -> c_int;
     #[cfg(Py_3_5)]
     pub fn PyModule_SetDocString(arg1: *mut PyObject, arg2: *const c_char) -> c_int;
     #[cfg(Py_3_5)]
@@ -121,3 +126,9 @@ pub unsafe fn PyModule_FromDefAndSpec(def: *mut PyModuleDef, spec: *mut PyObject
         },
     )
 }
+
+#[cfg(not(Py_LIMITED_API))]
+#[cfg_attr(windows, link(name = "pythonXY"))]
+extern "C" {
+    pub static mut _Py_PackageContext: *const c_char;
+}
