@@ -1,6 +1,7 @@
 use core::ptr;
 use libc::{c_char, c_int, c_uint, c_ulong, c_void};
-use pyport::{Py_hash_t, Py_ssize_t};
+
+use crate::pyport::{Py_hash_t, Py_ssize_t};
 
 #[repr(C)]
 #[derive(Copy, Clone)]
@@ -77,13 +78,14 @@ pub type objobjargproc =
 #[cfg(not(Py_LIMITED_API))]
 mod bufferinfo {
     use libc::{c_char, c_int, c_void};
-    use pyport::Py_ssize_t;
+
+    use crate::pyport::Py_ssize_t;
 
     #[repr(C)]
     #[derive(Copy)]
     pub struct Py_buffer {
         pub buf: *mut c_void,
-        pub obj: *mut ::object::PyObject,
+        pub obj: *mut crate::object::PyObject,
         pub len: Py_ssize_t,
         pub itemsize: Py_ssize_t,
         pub readonly: c_int,
@@ -103,14 +105,17 @@ mod bufferinfo {
     impl Default for Py_buffer {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
 
-    pub type getbufferproc =
-        extern "C" fn(arg1: *mut ::object::PyObject, arg2: *mut Py_buffer, arg3: c_int) -> c_int;
+    pub type getbufferproc = extern "C" fn(
+        arg1: *mut crate::object::PyObject,
+        arg2: *mut Py_buffer,
+        arg3: c_int,
+    ) -> c_int;
     pub type releasebufferproc =
-        extern "C" fn(arg1: *mut ::object::PyObject, arg2: *mut Py_buffer) -> ();
+        extern "C" fn(arg1: *mut crate::object::PyObject, arg2: *mut Py_buffer) -> ();
 
     /// Maximum number of dimensions
     pub const PyBUF_MAX_NDIM: c_int = 64;
@@ -155,7 +160,7 @@ pub type freefunc = unsafe extern "C" fn(arg1: *mut c_void);
 pub type destructor = unsafe extern "C" fn(arg1: *mut PyObject);
 #[cfg(not(Py_LIMITED_API))]
 pub type printfunc =
-    unsafe extern "C" fn(arg1: *mut PyObject, arg2: *mut ::libc::FILE, arg3: c_int) -> c_int;
+    unsafe extern "C" fn(arg1: *mut PyObject, arg2: *mut libc::FILE, arg3: c_int) -> c_int;
 pub type getattrfunc =
     unsafe extern "C" fn(arg1: *mut PyObject, arg2: *mut c_char) -> *mut PyObject;
 pub type getattrofunc =
@@ -189,11 +194,11 @@ pub type allocfunc =
 
 #[cfg(Py_3_8)]
 pub type vectorcallfunc = unsafe extern "C" fn(
-    callable: *mut ::object::PyObject,
-    args: *const *mut ::object::PyObject,
-    nargsf: ::libc::size_t,
-    kwnames: *mut ::object::PyObject,
-) -> *mut ::object::PyObject;
+    callable: *mut crate::object::PyObject,
+    args: *const *mut crate::object::PyObject,
+    nargsf: libc::size_t,
+    kwnames: *mut crate::object::PyObject,
+) -> *mut crate::object::PyObject;
 
 #[cfg(Py_LIMITED_API)]
 pub enum PyTypeObject {}
@@ -201,49 +206,50 @@ pub enum PyTypeObject {}
 #[cfg(not(Py_LIMITED_API))]
 mod typeobject {
     use libc::{c_char, c_uint, c_ulong, c_void};
-    use pyport::Py_ssize_t;
+
+    use crate::pyport::Py_ssize_t;
 
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyNumberMethods {
-        pub nb_add: Option<::object::binaryfunc>,
-        pub nb_subtract: Option<::object::binaryfunc>,
-        pub nb_multiply: Option<::object::binaryfunc>,
-        pub nb_remainder: Option<::object::binaryfunc>,
-        pub nb_divmod: Option<::object::binaryfunc>,
-        pub nb_power: Option<::object::ternaryfunc>,
-        pub nb_negative: Option<::object::unaryfunc>,
-        pub nb_positive: Option<::object::unaryfunc>,
-        pub nb_absolute: Option<::object::unaryfunc>,
-        pub nb_bool: Option<::object::inquiry>,
-        pub nb_invert: Option<::object::unaryfunc>,
-        pub nb_lshift: Option<::object::binaryfunc>,
-        pub nb_rshift: Option<::object::binaryfunc>,
-        pub nb_and: Option<::object::binaryfunc>,
-        pub nb_xor: Option<::object::binaryfunc>,
-        pub nb_or: Option<::object::binaryfunc>,
-        pub nb_int: Option<::object::unaryfunc>,
+        pub nb_add: Option<crate::object::binaryfunc>,
+        pub nb_subtract: Option<crate::object::binaryfunc>,
+        pub nb_multiply: Option<crate::object::binaryfunc>,
+        pub nb_remainder: Option<crate::object::binaryfunc>,
+        pub nb_divmod: Option<crate::object::binaryfunc>,
+        pub nb_power: Option<crate::object::ternaryfunc>,
+        pub nb_negative: Option<crate::object::unaryfunc>,
+        pub nb_positive: Option<crate::object::unaryfunc>,
+        pub nb_absolute: Option<crate::object::unaryfunc>,
+        pub nb_bool: Option<crate::object::inquiry>,
+        pub nb_invert: Option<crate::object::unaryfunc>,
+        pub nb_lshift: Option<crate::object::binaryfunc>,
+        pub nb_rshift: Option<crate::object::binaryfunc>,
+        pub nb_and: Option<crate::object::binaryfunc>,
+        pub nb_xor: Option<crate::object::binaryfunc>,
+        pub nb_or: Option<crate::object::binaryfunc>,
+        pub nb_int: Option<crate::object::unaryfunc>,
         pub nb_reserved: *mut c_void,
-        pub nb_float: Option<::object::unaryfunc>,
-        pub nb_inplace_add: Option<::object::binaryfunc>,
-        pub nb_inplace_subtract: Option<::object::binaryfunc>,
-        pub nb_inplace_multiply: Option<::object::binaryfunc>,
-        pub nb_inplace_remainder: Option<::object::binaryfunc>,
-        pub nb_inplace_power: Option<::object::ternaryfunc>,
-        pub nb_inplace_lshift: Option<::object::binaryfunc>,
-        pub nb_inplace_rshift: Option<::object::binaryfunc>,
-        pub nb_inplace_and: Option<::object::binaryfunc>,
-        pub nb_inplace_xor: Option<::object::binaryfunc>,
-        pub nb_inplace_or: Option<::object::binaryfunc>,
-        pub nb_floor_divide: Option<::object::binaryfunc>,
-        pub nb_true_divide: Option<::object::binaryfunc>,
-        pub nb_inplace_floor_divide: Option<::object::binaryfunc>,
-        pub nb_inplace_true_divide: Option<::object::binaryfunc>,
-        pub nb_index: Option<::object::unaryfunc>,
+        pub nb_float: Option<crate::object::unaryfunc>,
+        pub nb_inplace_add: Option<crate::object::binaryfunc>,
+        pub nb_inplace_subtract: Option<crate::object::binaryfunc>,
+        pub nb_inplace_multiply: Option<crate::object::binaryfunc>,
+        pub nb_inplace_remainder: Option<crate::object::binaryfunc>,
+        pub nb_inplace_power: Option<crate::object::ternaryfunc>,
+        pub nb_inplace_lshift: Option<crate::object::binaryfunc>,
+        pub nb_inplace_rshift: Option<crate::object::binaryfunc>,
+        pub nb_inplace_and: Option<crate::object::binaryfunc>,
+        pub nb_inplace_xor: Option<crate::object::binaryfunc>,
+        pub nb_inplace_or: Option<crate::object::binaryfunc>,
+        pub nb_floor_divide: Option<crate::object::binaryfunc>,
+        pub nb_true_divide: Option<crate::object::binaryfunc>,
+        pub nb_inplace_floor_divide: Option<crate::object::binaryfunc>,
+        pub nb_inplace_true_divide: Option<crate::object::binaryfunc>,
+        pub nb_index: Option<crate::object::unaryfunc>,
         #[cfg(Py_3_5)]
-        pub nb_matrix_multiply: Option<::object::binaryfunc>,
+        pub nb_matrix_multiply: Option<crate::object::binaryfunc>,
         #[cfg(Py_3_5)]
-        pub nb_inplace_matrix_multiply: Option<::object::binaryfunc>,
+        pub nb_inplace_matrix_multiply: Option<crate::object::binaryfunc>,
     }
     impl Clone for PyNumberMethods {
         #[inline]
@@ -254,7 +260,7 @@ mod typeobject {
     impl Default for PyNumberMethods {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
     macro_rules! as_expr {
@@ -319,16 +325,16 @@ mod typeobject {
     #[repr(C)]
     #[derive(Copy)]
     pub struct PySequenceMethods {
-        pub sq_length: Option<::object::lenfunc>,
-        pub sq_concat: Option<::object::binaryfunc>,
-        pub sq_repeat: Option<::object::ssizeargfunc>,
-        pub sq_item: Option<::object::ssizeargfunc>,
+        pub sq_length: Option<crate::object::lenfunc>,
+        pub sq_concat: Option<crate::object::binaryfunc>,
+        pub sq_repeat: Option<crate::object::ssizeargfunc>,
+        pub sq_item: Option<crate::object::ssizeargfunc>,
         pub was_sq_slice: *mut c_void,
-        pub sq_ass_item: Option<::object::ssizeobjargproc>,
+        pub sq_ass_item: Option<crate::object::ssizeobjargproc>,
         pub was_sq_ass_slice: *mut c_void,
-        pub sq_contains: Option<::object::objobjproc>,
-        pub sq_inplace_concat: Option<::object::binaryfunc>,
-        pub sq_inplace_repeat: Option<::object::ssizeargfunc>,
+        pub sq_contains: Option<crate::object::objobjproc>,
+        pub sq_inplace_concat: Option<crate::object::binaryfunc>,
+        pub sq_inplace_repeat: Option<crate::object::ssizeargfunc>,
     }
     impl Clone for PySequenceMethods {
         #[inline]
@@ -339,7 +345,7 @@ mod typeobject {
     impl Default for PySequenceMethods {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
     pub const PySequenceMethods_INIT: PySequenceMethods = PySequenceMethods {
@@ -357,9 +363,9 @@ mod typeobject {
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyMappingMethods {
-        pub mp_length: Option<::object::lenfunc>,
-        pub mp_subscript: Option<::object::binaryfunc>,
-        pub mp_ass_subscript: Option<::object::objobjargproc>,
+        pub mp_length: Option<crate::object::lenfunc>,
+        pub mp_subscript: Option<crate::object::binaryfunc>,
+        pub mp_ass_subscript: Option<crate::object::objobjargproc>,
     }
     impl Clone for PyMappingMethods {
         #[inline]
@@ -370,7 +376,7 @@ mod typeobject {
     impl Default for PyMappingMethods {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
     pub const PyMappingMethods_INIT: PyMappingMethods = PyMappingMethods {
@@ -382,9 +388,9 @@ mod typeobject {
     #[derive(Copy)]
     #[cfg(Py_3_5)]
     pub struct PyAsyncMethods {
-        pub am_await: Option<::object::unaryfunc>,
-        pub am_aiter: Option<::object::unaryfunc>,
-        pub am_anext: Option<::object::unaryfunc>,
+        pub am_await: Option<crate::object::unaryfunc>,
+        pub am_aiter: Option<crate::object::unaryfunc>,
+        pub am_anext: Option<crate::object::unaryfunc>,
     }
     #[cfg(Py_3_5)]
     impl Clone for PyAsyncMethods {
@@ -397,7 +403,7 @@ mod typeobject {
     impl Default for PyAsyncMethods {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
     #[cfg(Py_3_5)]
@@ -409,8 +415,8 @@ mod typeobject {
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyBufferProcs {
-        pub bf_getbuffer: Option<::object::getbufferproc>,
-        pub bf_releasebuffer: Option<::object::releasebufferproc>,
+        pub bf_getbuffer: Option<crate::object::getbufferproc>,
+        pub bf_releasebuffer: Option<crate::object::releasebufferproc>,
     }
     impl Clone for PyBufferProcs {
         #[inline]
@@ -421,81 +427,81 @@ mod typeobject {
     impl Default for PyBufferProcs {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
 
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyTypeObject {
-        pub ob_base: ::object::PyVarObject,
+        pub ob_base: crate::object::PyVarObject,
         pub tp_name: *const c_char,
         pub tp_basicsize: Py_ssize_t,
         pub tp_itemsize: Py_ssize_t,
-        pub tp_dealloc: Option<::object::destructor>,
+        pub tp_dealloc: Option<crate::object::destructor>,
         #[cfg(not(Py_3_8))]
-        pub tp_print: Option<::object::printfunc>,
+        pub tp_print: Option<crate::object::printfunc>,
         #[cfg(Py_3_8)]
         pub tp_vectorcall_offset: Py_ssize_t,
-        pub tp_getattr: Option<::object::getattrfunc>,
-        pub tp_setattr: Option<::object::setattrfunc>,
+        pub tp_getattr: Option<crate::object::getattrfunc>,
+        pub tp_setattr: Option<crate::object::setattrfunc>,
         #[cfg(Py_3_5)]
         pub tp_as_async: *mut PyAsyncMethods,
         #[cfg(not(Py_3_5))]
         pub tp_reserved: *mut c_void,
-        pub tp_repr: Option<::object::reprfunc>,
+        pub tp_repr: Option<crate::object::reprfunc>,
         pub tp_as_number: *mut PyNumberMethods,
         pub tp_as_sequence: *mut PySequenceMethods,
         pub tp_as_mapping: *mut PyMappingMethods,
-        pub tp_hash: Option<::object::hashfunc>,
-        pub tp_call: Option<::object::ternaryfunc>,
-        pub tp_str: Option<::object::reprfunc>,
-        pub tp_getattro: Option<::object::getattrofunc>,
-        pub tp_setattro: Option<::object::setattrofunc>,
+        pub tp_hash: Option<crate::object::hashfunc>,
+        pub tp_call: Option<crate::object::ternaryfunc>,
+        pub tp_str: Option<crate::object::reprfunc>,
+        pub tp_getattro: Option<crate::object::getattrofunc>,
+        pub tp_setattro: Option<crate::object::setattrofunc>,
         pub tp_as_buffer: *mut PyBufferProcs,
         pub tp_flags: c_ulong,
         pub tp_doc: *const c_char,
-        pub tp_traverse: Option<::object::traverseproc>,
-        pub tp_clear: Option<::object::inquiry>,
-        pub tp_richcompare: Option<::object::richcmpfunc>,
+        pub tp_traverse: Option<crate::object::traverseproc>,
+        pub tp_clear: Option<crate::object::inquiry>,
+        pub tp_richcompare: Option<crate::object::richcmpfunc>,
         pub tp_weaklistoffset: Py_ssize_t,
-        pub tp_iter: Option<::object::getiterfunc>,
-        pub tp_iternext: Option<::object::iternextfunc>,
-        pub tp_methods: *mut ::methodobject::PyMethodDef,
-        pub tp_members: *mut ::structmember::PyMemberDef,
-        pub tp_getset: *mut ::descrobject::PyGetSetDef,
+        pub tp_iter: Option<crate::object::getiterfunc>,
+        pub tp_iternext: Option<crate::object::iternextfunc>,
+        pub tp_methods: *mut crate::methodobject::PyMethodDef,
+        pub tp_members: *mut crate::structmember::PyMemberDef,
+        pub tp_getset: *mut crate::descrobject::PyGetSetDef,
         pub tp_base: *mut PyTypeObject,
-        pub tp_dict: *mut ::object::PyObject,
-        pub tp_descr_get: Option<::object::descrgetfunc>,
-        pub tp_descr_set: Option<::object::descrsetfunc>,
+        pub tp_dict: *mut crate::object::PyObject,
+        pub tp_descr_get: Option<crate::object::descrgetfunc>,
+        pub tp_descr_set: Option<crate::object::descrsetfunc>,
         pub tp_dictoffset: Py_ssize_t,
-        pub tp_init: Option<::object::initproc>,
-        pub tp_alloc: Option<::object::allocfunc>,
-        pub tp_new: Option<::object::newfunc>,
-        pub tp_free: Option<::object::freefunc>,
-        pub tp_is_gc: Option<::object::inquiry>,
-        pub tp_bases: *mut ::object::PyObject,
-        pub tp_mro: *mut ::object::PyObject,
-        pub tp_cache: *mut ::object::PyObject,
-        pub tp_subclasses: *mut ::object::PyObject,
-        pub tp_weaklist: *mut ::object::PyObject,
-        pub tp_del: Option<::object::destructor>,
+        pub tp_init: Option<crate::object::initproc>,
+        pub tp_alloc: Option<crate::object::allocfunc>,
+        pub tp_new: Option<crate::object::newfunc>,
+        pub tp_free: Option<crate::object::freefunc>,
+        pub tp_is_gc: Option<crate::object::inquiry>,
+        pub tp_bases: *mut crate::object::PyObject,
+        pub tp_mro: *mut crate::object::PyObject,
+        pub tp_cache: *mut crate::object::PyObject,
+        pub tp_subclasses: *mut crate::object::PyObject,
+        pub tp_weaklist: *mut crate::object::PyObject,
+        pub tp_del: Option<crate::object::destructor>,
         pub tp_version_tag: c_uint,
         #[cfg(Py_3_4)]
-        pub tp_finalize: Option<::object::destructor>,
+        pub tp_finalize: Option<crate::object::destructor>,
         #[cfg(Py_3_8)]
-        pub tp_vectorcall: Option<::object::vectorcallfunc>,
-        #[cfg(Py_3_8)]
-        pub tp_print: Option<::object::printfunc>,
-        #[cfg(py_sys_config = "COUNT_ALLOCS")]
+        pub tp_vectorcall: Option<crate::object::vectorcallfunc>,
+        #[cfg(all(Py_3_8, not(Py_3_9)))]
+        pub tp_print: Option<crate::object::printfunc>,
+        #[cfg(all(py_sys_config = "COUNT_ALLOCS", not(Py_3_9)))]
         pub tp_allocs: Py_ssize_t,
-        #[cfg(py_sys_config = "COUNT_ALLOCS")]
+        #[cfg(all(py_sys_config = "COUNT_ALLOCS", not(Py_3_9)))]
         pub tp_frees: Py_ssize_t,
-        #[cfg(py_sys_config = "COUNT_ALLOCS")]
+        #[cfg(all(py_sys_config = "COUNT_ALLOCS", not(Py_3_9)))]
         pub tp_maxalloc: Py_ssize_t,
-        #[cfg(py_sys_config = "COUNT_ALLOCS")]
+        #[cfg(all(py_sys_config = "COUNT_ALLOCS", not(Py_3_9)))]
         pub tp_prev: *mut PyTypeObject,
-        #[cfg(py_sys_config = "COUNT_ALLOCS")]
+        #[cfg(all(py_sys_config = "COUNT_ALLOCS", not(Py_3_9)))]
         pub tp_next: *mut PyTypeObject,
     }
     impl Clone for PyTypeObject {
@@ -509,15 +515,14 @@ mod typeobject {
         ($($tail:tt)*) => {
             as_expr! {
                 PyTypeObject {
-                    ob_base: ::object::PyVarObject {
-                        ob_base: ::object::PyObject_HEAD_INIT,
+                    ob_base: crate::object::PyVarObject {
+                        ob_base: crate::object::PyObject_HEAD_INIT,
                         ob_size: 0
                     },
                     tp_name: 0 as *const c_char,
                     tp_basicsize: 0,
                     tp_itemsize: 0,
                     tp_dealloc: None,
-                    tp_print: None,
                     tp_getattr: None,
                     tp_setattr: None,
                     tp_repr: None,
@@ -530,7 +535,7 @@ mod typeobject {
                     tp_getattro: None,
                     tp_setattro: None,
                     tp_as_buffer: 0 as *mut PyBufferProcs,
-                    tp_flags: ::object::Py_TPFLAGS_DEFAULT,
+                    tp_flags: crate::object::Py_TPFLAGS_DEFAULT,
                     tp_doc: 0 as *const c_char,
                     tp_traverse: None,
                     tp_clear: None,
@@ -538,11 +543,11 @@ mod typeobject {
                     tp_weaklistoffset: 0,
                     tp_iter: None,
                     tp_iternext: None,
-                    tp_methods: 0 as *mut ::methodobject::PyMethodDef,
-                    tp_members: 0 as *mut ::structmember::PyMemberDef,
-                    tp_getset: 0 as *mut ::descrobject::PyGetSetDef,
+                    tp_methods: 0 as *mut crate::methodobject::PyMethodDef,
+                    tp_members: 0 as *mut crate::structmember::PyMemberDef,
+                    tp_getset: 0 as *mut crate::descrobject::PyGetSetDef,
                     tp_base: 0 as *mut PyTypeObject,
-                    tp_dict: 0 as *mut ::object::PyObject,
+                    tp_dict: 0 as *mut crate::object::PyObject,
                     tp_descr_get: None,
                     tp_descr_set: None,
                     tp_dictoffset: 0,
@@ -551,11 +556,11 @@ mod typeobject {
                     tp_new: None,
                     tp_free: None,
                     tp_is_gc: None,
-                    tp_bases: 0 as *mut ::object::PyObject,
-                    tp_mro: 0 as *mut ::object::PyObject,
-                    tp_cache: 0 as *mut ::object::PyObject,
-                    tp_subclasses: 0 as *mut ::object::PyObject,
-                    tp_weaklist: 0 as *mut ::object::PyObject,
+                    tp_bases: 0 as *mut crate::object::PyObject,
+                    tp_mro: 0 as *mut crate::object::PyObject,
+                    tp_cache: 0 as *mut crate::object::PyObject,
+                    tp_subclasses: 0 as *mut crate::object::PyObject,
+                    tp_weaklist: 0 as *mut crate::object::PyObject,
                     tp_del: None,
                     tp_version_tag: 0,
                     $($tail)*
@@ -585,7 +590,7 @@ mod typeobject {
         }
     }
 
-    #[cfg(Py_3_8)]
+    #[cfg(Py_3_9)]
     pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
         tp_as_async: 0 as *mut PyAsyncMethods,
         tp_vectorcall_offset: 0,
@@ -593,20 +598,32 @@ mod typeobject {
         tp_finalize: None,
     );
 
+    #[cfg(all(Py_3_8, not(Py_3_9)))]
+    pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_print: None,
+        tp_as_async: 0 as *mut PyAsyncMethods,
+        tp_vectorcall_offset: 0,
+        tp_vectorcall: None,
+        tp_finalize: None,
+    );
+
     #[cfg(all(Py_3_5, not(Py_3_8)))]
     pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_print: None,
         tp_as_async: 0 as *mut PyAsyncMethods,
         tp_finalize: None,
     );
 
     #[cfg(all(Py_3_4, not(Py_3_5)))]
     pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_print: None,
         tp_reserved: 0 as *mut c_void,
         tp_finalize: None,
     );
 
     #[cfg(not(Py_3_4))]
     pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_print: None,
         tp_reserved: 0 as *mut c_void,
     );
 
@@ -627,10 +644,12 @@ mod typeobject {
         pub as_mapping: PyMappingMethods,
         pub as_sequence: PySequenceMethods,
         pub as_buffer: PyBufferProcs,
-        pub ht_name: *mut ::object::PyObject,
-        pub ht_slots: *mut ::object::PyObject,
-        pub ht_qualname: *mut ::object::PyObject,
+        pub ht_name: *mut crate::object::PyObject,
+        pub ht_slots: *mut crate::object::PyObject,
+        pub ht_qualname: *mut crate::object::PyObject,
         pub ht_cached_keys: *mut c_void,
+        #[cfg(Py_3_9)]
+        pub ht_module: *mut crate::object::PyObject,
     }
     impl Clone for PyHeapTypeObject {
         #[inline]
@@ -641,17 +660,17 @@ mod typeobject {
     impl Default for PyHeapTypeObject {
         #[inline]
         fn default() -> Self {
-            unsafe { ::core::mem::zeroed() }
+            unsafe { core::mem::zeroed() }
         }
     }
 
     #[inline]
     pub unsafe fn PyHeapType_GET_MEMBERS(
         etype: *mut PyHeapTypeObject,
-    ) -> *mut ::structmember::PyMemberDef {
-        (etype as *mut c_char)
-            .offset((*::object::Py_TYPE(etype as *mut ::object::PyObject)).tp_basicsize as isize)
-            as *mut ::structmember::PyMemberDef
+    ) -> *mut crate::structmember::PyMemberDef {
+        (etype as *mut c_char).offset(
+            (*crate::object::Py_TYPE(etype as *mut crate::object::PyObject)).tp_basicsize as isize,
+        ) as *mut crate::structmember::PyMemberDef
     }
 }
 #[cfg(not(Py_LIMITED_API))]
@@ -670,7 +689,7 @@ impl Clone for PyType_Slot {
 }
 impl Default for PyType_Slot {
     fn default() -> PyType_Slot {
-        unsafe { ::core::mem::zeroed() }
+        unsafe { core::mem::zeroed() }
     }
 }
 
@@ -690,7 +709,7 @@ impl Clone for PyType_Spec {
 }
 impl Default for PyType_Spec {
     fn default() -> PyType_Spec {
-        unsafe { ::core::mem::zeroed() }
+        unsafe { core::mem::zeroed() }
     }
 }
 
@@ -703,6 +722,16 @@ extern "C" {
 
     #[cfg(Py_3_4)]
     pub fn PyType_GetSlot(arg1: *mut PyTypeObject, arg2: c_int) -> *mut c_void;
+
+
+    #[cfg(Py_3_9)]
+    pub fn PyType_FromModuleAndSpec(arg1: *mut PyObject, arg2: *mut PyType_Spec, arg3: *mut PyObject) -> *mut PyObject;
+
+    #[cfg(Py_3_9)]
+    pub fn PyType_GetModule(arg1: *mut PyTypeObject) -> *mut PyObject;
+
+    #[cfg(Py_3_9)]
+    pub fn PyType_GetModuleState(arg1: *mut PyTypeObject) -> *mut c_void;
 }
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
@@ -750,7 +779,7 @@ extern "C" {
     pub fn PyType_Modified(t: *mut PyTypeObject);
 
     #[cfg(not(Py_LIMITED_API))]
-    pub fn PyObject_Print(o: *mut PyObject, fp: *mut ::libc::FILE, flags: c_int) -> c_int;
+    pub fn PyObject_Print(o: *mut PyObject, fp: *mut libc::FILE, flags: c_int) -> c_int;
     pub fn PyObject_Repr(o: *mut PyObject) -> *mut PyObject;
     pub fn PyObject_Str(o: *mut PyObject) -> *mut PyObject;
     pub fn PyObject_ASCII(arg1: *mut PyObject) -> *mut PyObject;
@@ -816,6 +845,9 @@ pub const Py_TPFLAGS_HEAPTYPE: c_ulong = (1 << 9);
 /// Set if the type allows subclassing
 pub const Py_TPFLAGS_BASETYPE: c_ulong = (1 << 10);
 
+#[cfg(all(Py_3_8, not(Py_LIMITED_API)))]
+pub const Py_TPFLAGS_HAVE_VECTORCALL: c_ulong = (1 << 11);
+
 /// Set if the type is 'ready' -- fully initialized
 pub const Py_TPFLAGS_READY: c_ulong = (1 << 12);
 
